@@ -19,14 +19,17 @@ from openstack.block_storage.v2 import extension as _extension
 from openstack.block_storage.v2 import limits as _limits
 from openstack.block_storage.v2 import quota_class_set as _quota_class_set
 from openstack.block_storage.v2 import quota_set as _quota_set
+from openstack.block_storage.v2 import service as _service
 from openstack.block_storage.v2 import snapshot as _snapshot
 from openstack.block_storage.v2 import stats as _stats
+from openstack.block_storage.v2 import transfer as _transfer
 from openstack.block_storage.v2 import type as _type
 from openstack.block_storage.v2 import volume as _volume
 from openstack import exceptions
 from openstack.identity.v3 import project as _project
 from openstack import proxy
 from openstack import resource
+from openstack import utils
 from openstack import warnings as os_warnings
 
 
@@ -181,6 +184,18 @@ class Proxy(proxy.Proxy):
         """
         return self._create(_snapshot.Snapshot, **attrs)
 
+    def update_snapshot(self, snapshot, **attrs):
+        """Update a snapshot
+
+        :param snapshot: Either the ID of a snapshot or a
+            :class:`~openstack.block_storage.v2.snapshot.Snapshot` instance.
+        :param dict attrs: The attributes to update on the snapshot.
+
+        :returns: The updated snapshot
+        :rtype: :class:`~openstack.block_storage.v2.snapshot.Snapshot`
+        """
+        return self._update(_snapshot.Snapshot, snapshot, **attrs)
+
     def delete_snapshot(self, snapshot, ignore_missing=True):
         """Delete a snapshot
 
@@ -201,7 +216,7 @@ class Proxy(proxy.Proxy):
 
     # ========== Snapshot actions ==========
 
-    def reset_snapshot(self, snapshot, status):
+    def reset_snapshot_status(self, snapshot, status):
         """Reset status of the snapshot
 
         :param snapshot: The value can be either the ID of a backup or a
@@ -211,7 +226,39 @@ class Proxy(proxy.Proxy):
         :returns: None
         """
         snapshot = self._get_resource(_snapshot.Snapshot, snapshot)
-        snapshot.reset(self, status)
+        snapshot.reset_status(self, status)
+
+    def reset_snapshot(self, snapshot, status):
+        warnings.warn(
+            "reset_snapshot is a deprecated alias for reset_snapshot_status "
+            "and will be removed in a future release.",
+            os_warnings.RemovedInSDK60Warning,
+        )
+        return self.reset_snapshot_status(snapshot, status)
+
+    def manage_snapshot(self, **attrs):
+        """Creates a snapshot by using existing storage rather than
+        allocating new storage.
+
+        :param dict attrs: Keyword arguments which will be used to create
+            a :class:`~openstack.block_storage.v2.snapshot.Snapshot`,
+            comprised of the properties on the Snapshot class.
+
+        :returns: The results of snapshot creation
+        :rtype: :class:`~openstack.block_storage.v2.snapshot.Snapshot`
+        """
+        return _snapshot.Snapshot.manage(self, **attrs)
+
+    def unmanage_snapshot(self, snapshot):
+        """Unmanage a snapshot from block storage provisioning.
+
+        :param snapshot: Either the ID of a snapshot or a
+            :class:`~openstack.block_storage.v2.snapshot.Snapshot`.
+
+        :returns: None
+        """
+        snapshot_obj = self._get_resource(_snapshot.Snapshot, snapshot)
+        snapshot_obj.unmanage(self)
 
     # ========== Types ==========
 
@@ -407,7 +454,9 @@ class Proxy(proxy.Proxy):
         """
         return self._create(_volume.Volume, **attrs)
 
-    def delete_volume(self, volume, ignore_missing=True, force=False):
+    def delete_volume(
+        self, volume, ignore_missing=True, *, force=False, cascade=False
+    ):
         """Delete a volume
 
         :param volume: The value can be either the ID of a volume or a
@@ -418,14 +467,21 @@ class Proxy(proxy.Proxy):
             exception will be set when attempting to delete a nonexistent
             volume.
         :param bool force: Whether to try forcing volume deletion.
+        :param bool cascade: Whether to remove any snapshots along with the
+            volume.
 
         :returns: ``None``
         """
-        if not force:
-            self._delete(_volume.Volume, volume, ignore_missing=ignore_missing)
-        else:
-            volume = self._get_resource(_volume.Volume, volume)
-            volume.force_delete(self)
+        volume = self._get_resource(_volume.Volume, volume)
+        try:
+            if not force:
+                volume.delete(self, params={'cascade': cascade})
+            else:
+                volume.force_delete(self)
+        except exceptions.NotFoundException:
+            if ignore_missing:
+                return None
+            raise
 
     # ========== Volume actions ==========
 
@@ -660,6 +716,18 @@ class Proxy(proxy.Proxy):
         """
         return self._get(_backup.Backup, backup)
 
+    def export_record(self, backup):
+        """Get a backup
+
+        :param backup: The value can be the ID of a backup
+            or a :class:`~openstack.block_storage.v2.backup.Backup`
+            instance.
+
+        :returns: The backup export record fields
+        """
+        backup = self._get_resource(_backup.Backup, backup)
+        return backup.export(self)
+
     def find_backup(self, name_or_id, ignore_missing=True, *, details=True):
         """Find a single backup
 
@@ -733,7 +801,7 @@ class Proxy(proxy.Proxy):
         backup = self._get_resource(_backup.Backup, backup)
         return backup.restore(self, volume_id=volume_id, name=name)
 
-    def reset_backup(self, backup, status):
+    def reset_backup_status(self, backup, status):
         """Reset status of the backup
 
         :param backup: The value can be either the ID of a backup or a
@@ -743,7 +811,15 @@ class Proxy(proxy.Proxy):
         :returns: None
         """
         backup = self._get_resource(_backup.Backup, backup)
-        backup.reset(self, status)
+        backup.reset_status(self, status)
+
+    def reset_backup(self, backup, status):
+        warnings.warn(
+            "reset_backup is a deprecated alias for reset_backup_status "
+            "and will be removed in a future release.",
+            os_warnings.RemovedInSDK60Warning,
+        )
+        return self.reset_backup_status(backup, status)
 
     # ========== Limits ==========
 
@@ -758,10 +834,13 @@ class Proxy(proxy.Proxy):
             :class:`~openstack.block_storage.v2.limits.RateLimit`
         :rtype: :class:`~openstack.block_storage.v2.limits.Limits`
         """
-        params = {}
         if project:
-            params['project_id'] = resource.Resource._get_id(project)
-        return self._get(_limits.Limits, requires_id=False, **params)
+            return self._get(
+                _limits.Limits,
+                requires_id=False,
+                project_id=resource.Resource._get_id(project),
+            )
+        return self._get(_limits.Limits, requires_id=False)
 
     # ========== Capabilities ==========
 
@@ -883,7 +962,7 @@ class Proxy(proxy.Proxy):
             by ``quota_set``.
 
         :returns: The updated QuotaSet
-        :rtype: :class:`~openstack.block_storage.v3.quota_set.QuotaSet`
+        :rtype: :class:`~openstack.block_storage.v2.quota_set.QuotaSet`
         """
         if 'project_id' in attrs or isinstance(project, _quota_set.QuotaSet):
             warnings.warn(
@@ -909,6 +988,157 @@ class Proxy(proxy.Proxy):
             attrs['project_id'] = project.id
             return self._update(_quota_set.QuotaSet, None, **attrs)
 
+    # ========== Services ==========
+    @ty.overload
+    def find_service(
+        self,
+        name_or_id: str,
+        ignore_missing: ty.Literal[True] = True,
+        **query: ty.Any,
+    ) -> _service.Service | None: ...
+
+    @ty.overload
+    def find_service(
+        self,
+        name_or_id: str,
+        ignore_missing: ty.Literal[False],
+        **query: ty.Any,
+    ) -> _service.Service: ...
+
+    # excuse the duplication here: it's mypy's fault
+    # https://github.com/python/mypy/issues/14764
+    @ty.overload
+    def find_service(
+        self,
+        name_or_id: str,
+        ignore_missing: bool,
+        **query: ty.Any,
+    ) -> _service.Service | None: ...
+
+    def find_service(
+        self,
+        name_or_id: str,
+        ignore_missing: bool = True,
+        **query: ty.Any,
+    ) -> _service.Service | None:
+        """Find a single service
+
+        :param name_or_id: The name or ID of a service
+        :param bool ignore_missing: When set to ``False``
+            :class:`~openstack.exceptions.NotFoundException` will be raised when
+            the resource does not exist.
+            When set to ``True``, None will be returned when attempting to find
+            a nonexistent resource.
+        :param dict query: Additional attributes like 'host'
+
+        :returns: One: class:`~openstack.block_storage.v2.service.Service` or None
+        :raises: :class:`~openstack.exceptions.NotFoundException`
+            when no resource can be found.
+        :raises: :class:`~openstack.exceptions.DuplicateResource` when multiple
+            resources are found.
+        """
+        return self._find(
+            _service.Service,
+            name_or_id,
+            ignore_missing=ignore_missing,
+            **query,
+        )
+
+    def services(
+        self,
+        **query: ty.Any,
+    ) -> ty.Generator[_service.Service, None, None]:
+        """Return a generator of service
+
+        :param kwargs query: Optional query parameters to be sent to limit
+            the resources being returned.
+        :returns: A generator of Service objects
+        :rtype: class: `~openstack.block_storage.v2.service.Service`
+        """
+        return self._list(_service.Service, **query)
+
+    def enable_service(
+        self,
+        service: str | _service.Service,
+    ) -> _service.Service:
+        """Enable a service
+
+        :param service: Either the ID of a service or a
+            :class:`~openstack.block_storage.v2.service.Service` instance.
+
+        :returns: Updated service instance
+        :rtype: class: `~openstack.block_storage.v2.service.Service`
+        """
+        service_obj = self._get_resource(_service.Service, service)
+        return service_obj.enable(self)
+
+    def disable_service(
+        self,
+        service: str | _service.Service,
+        *,
+        reason: str | None = None,
+    ) -> _service.Service:
+        """Disable a service
+
+        :param service: Either the ID of a service or a
+            :class:`~openstack.block_storage.v2.service.Service` instance
+        :param str reason: The reason to disable a service
+
+        :returns: Updated service instance
+        :rtype: class: `~openstack.block_storage.v2.service.Service`
+        """
+        service_obj = self._get_resource(_service.Service, service)
+        return service_obj.disable(self, reason=reason)
+
+    def thaw_service(
+        self,
+        service: str | _service.Service,
+    ) -> _service.Service:
+        """Thaw a service
+
+        :param service: Either the ID of a service or a
+            :class:`~openstack.block_storage.v2.service.Service` instance
+
+        :returns: Updated service instance
+        :rtype: class: `~openstack.block_storage.v2.service.Service`
+        """
+        service_obj = self._get_resource(_service.Service, service)
+        return service_obj.thaw(self)
+
+    def freeze_service(
+        self,
+        service: str | _service.Service,
+    ) -> _service.Service:
+        """Freeze a service
+
+        :param service: Either the ID of a service or a
+            :class:`~openstack.block_storage.v2.service.Service` instance
+
+        :returns: Updated service instance
+        :rtype: class: `~openstack.block_storage.v2.service.Service`
+        """
+        service_obj = self._get_resource(_service.Service, service)
+        return service_obj.freeze(self)
+
+    def failover_service(
+        self,
+        service: str | _service.Service,
+        *,
+        backend_id: str | None = None,
+    ) -> _service.Service:
+        """Failover a service
+
+        Only applies to replicating cinder-volume services.
+
+        :param service: Either the ID of a service or a
+            :class:`~openstack.block_storage.v2.service.Service` instance
+
+        :returns: Updated service instance
+        :rtype: class: `~openstack.block_storage.v2.service.Service`
+        """
+        service_obj = self._get_resource(_service.Service, service)
+        return service_obj.failover(self, backend_id=backend_id)
+
     # ========== Volume metadata ==========
 
     def get_volume_metadata(self, volume):
@@ -1007,17 +1237,118 @@ class Proxy(proxy.Proxy):
         else:
             snapshot.delete_metadata(self)
 
+    # ========== Transfers ==========
+
+    def create_transfer(self, **attrs):
+        """Create a new Transfer record
+
+        :param volume_id: The value is ID of the volume.
+        :param name: The value is name of the transfer
+        :param dict attrs: Keyword arguments which will be used to create
+            a :class:`~openstack.block_storage.v2.transfer.Transfer`
+            comprised of the properties on the Transfer class.
+        :returns: The results of Transfer creation
+        :rtype: :class:`~openstack.block_storage.v2.transfer.Transfer`
+        """
+        return self._create(_transfer.Transfer, **attrs)
+
+    def delete_transfer(self, transfer, ignore_missing=True):
+        """Delete a volume transfer
+
+        :param transfer: The value can be either the ID of a transfer or a
+            :class:`~openstack.block_storage.v2.transfer.Transfer`` instance.
+        :param bool ignore_missing: When set to ``False``
+            :class:`~openstack.exceptions.NotFoundException` will be
+            raised when the transfer does not exist.
+            When set to ``True``, no exception will be set when
+            attempting to delete a nonexistent transfer.
+
+        :returns: ``None``
+        """
+        self._delete(
+            _transfer.Transfer,
+            transfer,
+            ignore_missing=ignore_missing,
+        )
+
+    def find_transfer(self, name_or_id, ignore_missing=True):
+        """Find a single transfer
+
+        :param name_or_id: The name or ID a transfer
+        :param bool ignore_missing: When set to ``False``
+            :class:`~openstack.exceptions.NotFoundException` will be raised
+            when the volume transfer does not exist.
+
+        :returns: One :class:`~openstack.block_storage.v2.transfer.Transfer`
+        :raises: :class:`~openstack.exceptions.NotFoundException`
+            when no resource can be found.
+        :raises: :class:`~openstack.exceptions.DuplicateResource` when multiple
+            resources are found.
+        """
+        return self._find(
+            _transfer.Transfer,
+            name_or_id,
+            ignore_missing=ignore_missing,
+        )
+
+    def get_transfer(self, transfer):
+        """Get a single transfer
+
+        :param transfer: The value can be the ID of a transfer or a
+            :class:`~openstack.block_storage.v2.transfer.Transfer`
+            instance.
+
+        :returns: One :class:`~openstack.block_storage.v2.transfer.Transfer`
+        :raises: :class:`~openstack.exceptions.NotFoundException`
+            when no resource can be found.
+        """
+        return self._get(_transfer.Transfer, transfer)
+
+    def transfers(self, *, details=True, all_projects=False, **query):
+        """Retrieve a generator of transfers
+
+        :param bool details: When set to ``False`` no extended attributes
+            will be returned. The default, ``True``, will cause objects with
+            additional attributes to be returned.
+        :param bool all_projects: When set to ``True``, list transfers from
+            all projects. Admin-only by default.
+        :param kwargs query: Optional query parameters to be sent to limit
+            the transfers being returned.
+
+        :returns: A generator of transfer objects.
+        """
+        if all_projects:
+            query['all_projects'] = True
+        base_path = '/volume-transfers'
+        if details:
+            base_path = utils.urljoin(base_path, 'detail')
+        return self._list(_transfer.Transfer, base_path=base_path, **query)
+
+    def accept_transfer(self, transfer_id, auth_key):
+        """Accept a Transfer
+
+        :param transfer_id: The value can be the ID of a transfer or a
+            :class:`~openstack.block_storage.v2.transfer.Transfer`
+            instance.
+        :param auth_key: The key to authenticate volume transfer.
+
+        :returns: The results of Transfer creation
+        :rtype: :class:`~openstack.block_storage.v2.transfer.Transfer`
+        """
+        transfer = self._get_resource(_transfer.Transfer, transfer_id)
+        return transfer.accept(self, auth_key=auth_key)
+
     # ========== Utilities ==========
 
     def wait_for_status(
         self,
         res: resource.ResourceT,
         status: str = 'available',
-        failures: ty.Optional[list[str]] = None,
-        interval: ty.Union[int, float, None] = 2,
-        wait: ty.Optional[int] = None,
+        failures: list[str] | None = None,
+        interval: int | float | None = 2,
+        wait: int | None = None,
         attribute: str = 'status',
-        callback: ty.Optional[ty.Callable[[int], None]] = None,
+        callback: ty.Callable[[int], None] | None = None,
     ) -> resource.ResourceT:
         """Wait for the resource to be in a particular status.
 
@@ -1056,7 +1387,7 @@ class Proxy(proxy.Proxy):
         res: resource.ResourceT,
         interval: int = 2,
         wait: int = 120,
-        callback: ty.Optional[ty.Callable[[int], None]] = None,
+        callback: ty.Callable[[int], None] | None = None,
     ) -> resource.ResourceT:
         """Wait for a resource to be deleted.
 
