@@ -10,10 +10,12 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import warnings
 
 from openstack import exceptions
 from openstack import resource
 from openstack import utils
+from openstack import warnings as os_warnings
 
 
 class Backup(resource.Resource):
@@ -40,7 +42,6 @@ class Backup(resource.Resource):
     allow_create = True
     allow_delete = True
     allow_list = True
-    allow_get = True
 
     #: Properties
     #: backup availability zone
@@ -108,7 +109,6 @@ class Backup(resource.Resource):
             raise exceptions.MethodNotSupported(self, "create")
 
         session = self._get_session(session)
-        microversion = self._get_microversion(session, action='create')
         requires_id = (
             self.create_requires_id
             if self.create_requires_id is not None
@@ -137,7 +137,6 @@ class Backup(resource.Resource):
                 request.url,
                 json=request.body,
                 headers=request.headers,
-                microversion=microversion,
                 params=params,
             )
         else:
@@ -151,7 +150,6 @@ class Backup(resource.Resource):
             if self.create_returns_body is None
             else self.create_returns_body
         )
-        self.microversion = microversion
         self._translate_response(response, has_body=has_body)
         # direct comparision to False since we need to rule out None
         if self.has_body and self.create_returns_body is False:
@@ -159,15 +157,24 @@ class Backup(resource.Resource):
             return self.fetch(session)
         return self
 
-    def _action(self, session, body, microversion=None):
+    def _action(self, session, body):
         """Preform backup actions given the message body."""
         url = utils.urljoin(self.base_path, self.id, 'action')
-        resp = session.post(
-            url, json=body, microversion=self._max_microversion
-        )
+        resp = session.post(url, json=body)
         exceptions.raise_from_response(resp)
         return resp
 
+    def export(self, session):
+        """Export the current backup
+
+        :param session: openstack session
+        :return: The backup export record fields
+        """
+        url = utils.urljoin(self.base_path, self.id, "export_record")
+        resp = session.get(url)
+        exceptions.raise_from_response(resp)
+        return resp.json()
+
     def restore(self, session, volume_id=None, name=None):
         """Restore current backup to volume
 
@@ -195,10 +202,18 @@ class Backup(resource.Resource):
         body = {'os-force_delete': None}
         self._action(session, body)
 
-    def reset(self, session, status):
+    def reset_status(self, session, status):
         """Reset the status of the backup"""
         body = {'os-reset_status': {'status': status}}
         self._action(session, body)
 
+    def reset(self, session, status):
+        warnings.warn(
+            "reset is a deprecated alias for reset_status and will be "
+            "removed in a future release.",
+            os_warnings.RemovedInSDK60Warning,
+        )
+        self.reset_status(session, status)
+
 
 BackupDetail = Backup
