@@ -10,23 +10,16 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# import types so that we can reference ListType in sphinx param declarations.
-# We can't just use list, because sphinx gets confused by
-# openstack.resource.Resource.list and openstack.resource2.Resource.list
 import concurrent.futures
-import types  # noqa
 import urllib.parse
+import warnings
 
 import keystoneauth1.exceptions
 
 from openstack.cloud import _utils
-from openstack.cloud import exc
+from openstack.cloud import openstackcloud
 from openstack import exceptions
-
-
-DEFAULT_OBJECT_SEGMENT_SIZE = 1073741824  # 1GB
-# This halves the current default for Swift
-DEFAULT_MAX_FILE_SIZE = (5 * 1024 * 1024 * 1024 + 2) / 2
+from openstack import warnings as os_warnings
 
 
 OBJECT_CONTAINER_ACLS = {
@@ -35,25 +28,23 @@ OBJECT_CONTAINER_ACLS = {
 }
 
 
-class ObjectStoreCloudMixin:
-
-    @property
-    def _object_store_client(self):
-        if 'object-store' not in self._raw_clients:
-            raw_client = self._get_raw_client('object-store')
-            self._raw_clients['object-store'] = raw_client
-        return self._raw_clients['object-store']
-
-    # TODO(stephenfin): Remove 'full_listing' as it's a noop
-    def list_containers(self, full_listing=True, prefix=None):
+class ObjectStoreCloudMixin(openstackcloud._OpenStackCloudMixin):
+    def list_containers(self, full_listing=None, prefix=None):
         """List containers.
 
         :param full_listing: Ignored. Present for backwards compat
         :param prefix: Only objects with this prefix will be returned.
             (optional)
         :returns: A list of object store ``Container`` objects.
-        :raises: OpenStackCloudException on operation error.
+        :raises: :class:`~openstack.exceptions.SDKException` on operation
+            error.
         """
+        if full_listing is not None:
+            warnings.warn(
+                "The 'full_listing' field is unnecessary and will be removed "
+                "in a future release.",
+                os_warnings.RemovedInSDK60Warning,
+            )
         return list(self.object_store.containers(prefix=prefix))
 
     def search_containers(self, name=None, filters=None):
@@ -67,31 +58,27 @@ class ObjectStoreCloudMixin:
 
         :returns: A list of object store ``Container`` objects matching the
             search criteria.
-        :raises: ``OpenStackCloudException``: If something goes wrong during
-            the OpenStack API call.
+        :raises: :class:`~openstack.exceptions.SDKException`: If something goes
+            wrong during the OpenStack API call.
         """
         containers = self.list_containers()
         return _utils._filter_list(containers, name, filters)
 
+    # TODO(stephenfin): Remove 'skip_cache' as it no longer does anything
     def get_container(self, name, skip_cache=False):
         """Get metadata about a container.
 
         :param str name:
             Name of the container to get metadata for.
-        :param bool skip_cache:
-            Ignore the cache of container metadata for this container.
-            Defaults to ``False``.
+        :param bool skip_cache: Ignored. Present for backwards compatibility.
         :returns: An object store ``Container`` object if found, else None.
         """
-        if skip_cache or name not in self._container_cache:
-            try:
-                container = self.object_store.get_container_metadata(name)
-                self._container_cache[name] = container
-            except exceptions.HttpException as ex:
-                if ex.response.status_code == 404:
-                    return None
-                raise
-        return self._container_cache[name]
+        try:
+            return self.object_store.get_container_metadata(name)
+        except exceptions.HttpException as ex:
+            if ex.response.status_code == 404:
+                return None
+            raise
 
     def create_container(self, name, public=False):
         """Create an object-store container.
@@ -104,9 +91,7 @@ class ObjectStoreCloudMixin:
         container = self.get_container(name)
         if container:
             return container
-        attrs = dict(
-            name=name
-        )
+        attrs = dict(name=name)
         if public:
             attrs['read_ACL'] = OBJECT_CONTAINER_ACLS['public']
         container = self.object_store.create_container(**attrs)
@@ -119,16 +104,15 @@ class ObjectStoreCloudMixin:
         """
         try:
             self.object_store.delete_container(name, ignore_missing=False)
-            self._container_cache.pop(name, None)
             return True
         except exceptions.NotFoundException:
             return False
         except exceptions.ConflictException:
-            raise exc.OpenStackCloudException(
-                'Attempt to delete container {container} failed. The'
-                ' container is not empty. Please delete the objects'
-                ' inside it before deleting the container'.format(
-                    container=name))
+            raise exceptions.SDKException(
+                f'Attempt to delete container {name} failed. The '
+                f'container is not empty. Please delete the objects '
+                f'inside it before deleting the container'
+            )
 
     def update_container(self, name, headers):
         """Update the metadata in a container.
@@ -137,7 +121,8 @@ class ObjectStoreCloudMixin:
         :param dict headers: Key/Value headers to set on the container.
         """
         self.object_store.set_container_metadata(
-            name, refresh=False, **headers)
+            name, refresh=False, **headers
+        )
 
     def set_container_access(self, name, access, refresh=False):
         """Set the access control list on a container.
@@ -149,13 +134,12 @@ class ObjectStoreCloudMixin:
         :param refresh: Flag to trigger refresh of the container properties
         """
         if access not in OBJECT_CONTAINER_ACLS:
-            raise exc.OpenStackCloudException(
-                "Invalid container access specified: %s.  Must be one of %s"
-                % (access, list(OBJECT_CONTAINER_ACLS.keys())))
+            raise exceptions.SDKException(
+                f"Invalid container access specified: {access}. "
+                f"Must be one of {list(OBJECT_CONTAINER_ACLS.keys())}"
+            )
         return self.object_store.set_container_metadata(
-            name,
-            read_ACL=OBJECT_CONTAINER_ACLS[access],
-            refresh=refresh
+            name, read_ACL=OBJECT_CONTAINER_ACLS[access], refresh=refresh
         )
 
     def get_container_access(self, name):
@@ -163,13 +147,12 @@ class ObjectStoreCloudMixin:
 
         :param str name: Name of the container.
         :returns: The contol list for the container.
-        :raises: :class:`~openstack.exceptions.OpenStackCloudException` if the
-            container was not found or container access could not be
-            determined.
+        :raises: :class:`~openstack.exceptions.SDKException` if the container
+            was not found or container access could not be determined.
         """
         container = self.get_container(name, skip_cache=True)
         if not container:
-            raise exc.OpenStackCloudException("Container not found: %s" % name)
+            raise exceptions.SDKException(f"Container not found: {name}")
         acl = container.read_ACL or ''
         for key, value in OBJECT_CONTAINER_ACLS.items():
             # Convert to string for the comparison because swiftclient
@@ -177,10 +160,10 @@ class ObjectStoreCloudMixin:
             # on bytes doesn't work like you'd think
             if str(acl) == str(value):
                 return key
-        raise exc.OpenStackCloudException(
-            "Could not determine container access for ACL: %s." % acl)
+        raise exceptions.SDKException(
+            f"Could not determine container access for ACL: {acl}."
+        )
 
-    @_utils.cache_on_arguments()
     def get_object_capabilities(self):
         """Get infomation about the object-storage service
 
@@ -200,7 +183,8 @@ class ObjectStoreCloudMixin:
         return self.object_store.get_object_segment_size(segment_size)
 
     def is_object_stale(
-            self, container, name, filename, file_md5=None, file_sha256=None):
+        self, container, name, filename, file_md5=None, file_sha256=None
+    ):
         """Check to see if an object matches the hashes of a file.
 
         :param container: Name of the container.
@@ -212,8 +196,11 @@ class ObjectStoreCloudMixin:
             Defaults to None which means calculate locally.
         """
         return self.object_store.is_object_stale(
-            container, name, filename,
-            file_md5=file_md5, file_sha256=file_sha256
+            container,
+            name,
+            filename,
+            file_md5=file_md5,
+            file_sha256=file_sha256,
         )
 
     def create_directory_marker_object(self, container, name, **headers):
@@ -240,11 +227,8 @@ class ObjectStoreCloudMixin:
         headers['content-type'] = 'application/directory'
 
         return self.create_object(
-            container,
-            name,
-            data='',
-            generate_checksums=False,
-            **headers)
+            container, name, data='', generate_checksums=False, **headers
+        )
 
     def create_object(
         self,
@@ -290,16 +274,22 @@ class ObjectStoreCloudMixin:
             uploads of identical data. (optional, defaults to True)
         :param metadata: This dict will get changed into headers that set
             metadata of the object
+
         :returns: The created object store ``Object`` object.
-        :raises: ``OpenStackCloudException`` on operation error.
+        :raises: :class:`~openstack.exceptions.SDKException` on operation
+            error.
         """
         return self.object_store.create_object(
-            container, name,
-            filename=filename, data=data,
-            md5=md5, sha256=sha256, use_slo=use_slo,
+            container,
+            name,
+            filename=filename,
+            data=data,
+            md5=md5,
+            sha256=sha256,
+            use_slo=use_slo,
             generate_checksums=generate_checksums,
             metadata=metadata,
-            **headers
+            **headers,
         )
 
     def update_object(self, container, name, metadata=None, **headers):
@@ -311,13 +301,14 @@ class ObjectStoreCloudMixin:
             metadata of the object
         :param headers: These will be passed through to the object update
             API as HTTP Headers.
+
         :returns: None
-        :raises: ``OpenStackCloudException`` on operation error.
+        :raises: :class:`~openstack.exceptions.SDKException` on operation
+            error.
         """
         meta = metadata.copy() or {}
         meta.update(**headers)
-        self.object_store.set_object_metadata(
-            name, container, **meta)
+        self.object_store.set_object_metadata(name, container, **meta)
 
     def list_objects(self, container, full_listing=True, prefix=None):
         """List objects.
@@ -326,13 +317,14 @@ class ObjectStoreCloudMixin:
         :param full_listing: Ignored. Present for backwards compat
         :param prefix: Only objects with this prefix will be returned.
             (optional)
+
         :returns: A list of object store ``Object`` objects.
-        :raises: OpenStackCloudException on operation error.
+        :raises: :class:`~openstack.exceptions.SDKException` on operation
+            error.
         """
-        return list(self.object_store.objects(
-            container=container,
-            prefix=prefix
-        ))
+        return list(
+            self.object_store.objects(container=container, prefix=prefix)
+        )
 
     def search_objects(self, container, name=None, filters=None):
         """Search objects.
@@ -345,8 +337,8 @@ class ObjectStoreCloudMixin:
 
         :returns: A list of object store ``Object`` objects matching the
             search criteria.
-        :raises: ``OpenStackCloudException``: If something goes wrong during
-            the OpenStack API call.
+        :raises: :class:`~openstack.exceptions.SDKException`: If something goes
+            wrong during the OpenStack API call.
         """
         objects = self.list_objects(container)
         return _utils._filter_list(objects, name, filters)
@@ -358,12 +350,16 @@ class ObjectStoreCloudMixin:
         :param string name: Name of the object to delete.
         :param dict meta: Metadata for the object in question. (optional, will
             be fetched if not provided)
+
         :returns: True if delete succeeded, False if the object was not found.
-        :raises: OpenStackCloudException on operation error.
+        :raises: :class:`~openstack.exceptions.SDKException` on operation
+            error.
         """
         try:
             self.object_store.delete_object(
-                name, ignore_missing=False, container=container,
+                name,
+                ignore_missing=False,
+                container=container,
             )
             return True
         except exceptions.SDKException:
@@ -399,9 +395,7 @@ class ObjectStoreCloudMixin:
         :param name:
         :returns: The object metadata.
         """
-        return self.object_store.get_object_metadata(
-            name, container
-        ).metadata
+        return self.object_store.get_object_metadata(name, container).metadata
 
     def get_object_raw(self, container, obj, query_string=None, stream=False):
         """Get a raw response object for an object.
@@ -411,22 +405,20 @@ class ObjectStoreCloudMixin:
         :param string query_string: Query args for uri. (delimiter, prefix,
             etc.)
         :param bool stream: Whether to stream the response or not.
+
         :returns: A `requests.Response`
-        :raises: OpenStackCloudException on operation error.
+        :raises: :class:`~openstack.exceptions.SDKException` on operation
+            error.
         """
         endpoint = self._get_object_endpoint(container, obj, query_string)
-        return self._object_store_client.get(endpoint, stream=stream)
+        return self.object_store.get(endpoint, stream=stream)
 
     def _get_object_endpoint(self, container, obj=None, query_string=None):
         endpoint = urllib.parse.quote(container)
         if obj:
-            endpoint = '{endpoint}/{object}'.format(
-                endpoint=endpoint,
-                object=urllib.parse.quote(obj)
-            )
+            endpoint = f'{endpoint}/{urllib.parse.quote(obj)}'
         if query_string:
-            endpoint = '{endpoint}?{query_string}'.format(
-                endpoint=endpoint, query_string=query_string)
+            endpoint = f'{endpoint}?{query_string}'
         return endpoint
 
     def stream_object(
@@ -444,19 +436,28 @@ class ObjectStoreCloudMixin:
             etc.)
         :param int resp_chunk_size: Chunk size of data to read. Only used if
             the results are
+
         :returns: An iterator over the content or None if the object is not
             found.
-        :raises: OpenStackCloudException on operation error.
+        :raises: :class:`~openstack.exceptions.SDKException` on operation
+            error.
         """
         try:
-            for ret in self.object_store.stream_object(
-                    obj, container, chunk_size=resp_chunk_size):
-                yield ret
-        except exceptions.ResourceNotFound:
+            yield from self.object_store.stream_object(
+                obj, container, chunk_size=resp_chunk_size
+            )
+        except exceptions.NotFoundException:
             return
 
-    def get_object(self, container, obj, query_string=None,
-                   resp_chunk_size=1024, outfile=None, stream=False):
+    def get_object(
+        self,
+        container,
+        obj,
+        query_string=None,
+        resp_chunk_size=1024,
+        outfile=None,
+        stream=False,
+    ):
         """Get the headers and body of an object
 
         :param string container: Name of the container.
@@ -470,22 +471,24 @@ class ObjectStoreCloudMixin:
             contents. If this option is given, body in the return tuple will be
             None. outfile can either be a file path given as a string, or a
             File like object.
+
         :returns: Tuple (headers, body) of the object, or None if the object
             is not found (404).
-        :raises: OpenStackCloudException on operation error.
+        :raises: :class:`~openstack.exceptions.SDKException` on operation
+            error.
         """
         try:
             obj = self.object_store.get_object(
-                obj, container=container,
+                obj,
+                container=container,
                 resp_chunk_size=resp_chunk_size,
                 outfile=outfile,
-                remember_content=(outfile is None)
+                remember_content=(outfile is None),
             )
-            headers = {
-                k.lower(): v for k, v in obj._last_headers.items()}
+            headers = {k.lower(): v for k, v in obj._last_headers.items()}
             return (headers, obj.data)
 
-        except exceptions.ResourceNotFound:
+        except exceptions.NotFoundException:
             return None
 
     def _wait_for_futures(self, futures, raise_on_error=True):
@@ -499,10 +502,11 @@ class ObjectStoreCloudMixin:
                 result = completed.result()
                 exceptions.raise_from_response(result)
                 results.append(result)
-            except (keystoneauth1.exceptions.RetriableConnectionFailure,
-                    exceptions.HttpException) as e:
-                error_text = "Exception processing async task: {}".format(
-                    str(e))
+            except (
+                keystoneauth1.exceptions.RetriableConnectionFailure,
+                exceptions.HttpException,
+            ) as e:
+                error_text = f"Exception processing async task: {str(e)}"
                 if raise_on_error:
                     self.log.exception(error_text)
                     raise
