@@ -10,7 +10,6 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from openstack.identity import identity_service
 from openstack import resource
 
 
@@ -18,22 +17,21 @@ class User(resource.Resource):
     resource_key = 'user'
     resources_key = 'users'
     base_path = '/users'
-    service = identity_service.AdminService()
 
     # capabilities
     allow_create = True
-    allow_retrieve = True
-    allow_update = True
+    allow_fetch = True
+    allow_commit = True
     allow_delete = True
     allow_list = True
 
     # Properties
     #: The email of this user. *Type: string*
-    email = resource.prop('email')
+    email = resource.Body('email')
     #: Setting this value to ``False`` prevents the user from authenticating or
     #: receiving authorization. Additionally, all pre-existing tokens held by
     #: the user are immediately invalidated. Re-enabling a user does not
     #: re-enable pre-existing tokens. *Type: bool*
-    enabled = resource.prop('enabled', type=bool)
+    is_enabled = resource.Body('enabled', type=bool)
     #: The name of this user. *Type: string*
-    name = resource.prop('name')
+    name = resource.Body('name')
