@@ -10,7 +10,6 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from openstack.identity import identity_service
 from openstack import resource
 
 
@@ -18,18 +17,23 @@ class Region(resource.Resource):
     resource_key = 'region'
     resources_key = 'regions'
     base_path = '/regions'
-    service = identity_service.IdentityService()
 
     # capabilities
     allow_create = True
-    allow_retrieve = True
-    allow_update = True
+    allow_fetch = True
+    allow_commit = True
     allow_delete = True
     allow_list = True
-    patch_update = True
+    commit_method = 'PATCH'
+
+    _query_mapping = resource.QueryParameters(
+        'parent_region_id',
+    )
 
     # Properties
     #: User-facing description of the region. *Type: string*
-    description = resource.prop('description')
+    description = resource.Body('description')
+    #: The links for the region resource.
+    links = resource.Body('links')
     #: ID of parent region, if any. *Type: string*
-    parent_region_id = resource.prop('parent_region_id')
+    parent_region_id = resource.Body('parent_region_id')
