@@ -10,7 +10,6 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from openstack.identity import identity_service
 from openstack import resource
 
 
@@ -18,27 +17,33 @@ class Service(resource.Resource):
     resource_key = 'service'
     resources_key = 'services'
     base_path = '/services'
-    service = identity_service.IdentityService()
 
     # capabilities
     allow_create = True
-    allow_retrieve = True
-    allow_update = True
+    allow_fetch = True
+    allow_commit = True
     allow_delete = True
     allow_list = True
-    patch_update = True
+    commit_method = 'PATCH'
+
+    _query_mapping = resource.QueryParameters(
+        'name',
+        'type',
+    )
 
     # Properties
     #: User-facing description of the service. *Type: string*
-    description = resource.prop('description')
+    description = resource.Body('description')
     #: Setting this value to ``False`` prevents the service and
     #: its endpoints from appearing in the service catalog. *Type: bool*
-    is_enabled = resource.prop('enabled', type=bool)
+    is_enabled = resource.Body('enabled', type=bool)
+    #: The links for the service resource.
+    links = resource.Body('links')
     #: User-facing name of the service. *Type: string*
-    name = resource.prop('name')
+    name = resource.Body('name')
     #: Describes the API implemented by the service. The following values are
     #: recognized within the OpenStack ecosystem: ``compute``, ``image``,
     #: ``ec2``, ``identity``, ``volume``, ``network``. To support non-core and
     #: future projects, the value should not be validated against this list.
     #: *Type: string*
-    type = resource.prop('type')
+    type = resource.Body('type')
