@@ -9,11 +9,11 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-
+from openstack.common import tag
 from openstack import resource
 
 
-class Pool(resource.Resource, resource.TagMixin):
+class Pool(resource.Resource, tag.TagMixin):
     resource_key = 'pool'
     resources_key = 'pools'
     base_path = '/lbaas/pools'
@@ -26,14 +26,31 @@ class Pool(resource.Resource, resource.TagMixin):
     allow_commit = True
 
     _query_mapping = resource.QueryParameters(
-        'health_monitor_id', 'lb_algorithm', 'listener_id', 'loadbalancer_id',
-        'description', 'name', 'project_id', 'protocol',
-        'created_at', 'updated_at', 'provisioning_status', 'operating_status',
-        'tls_ciphers', 'tls_versions', is_admin_state_up='admin_state_up',
-        **resource.TagMixin._tag_query_parameters
+        'health_monitor_id',
+        'lb_algorithm',
+        'listener_id',
+        'loadbalancer_id',
+        'description',
+        'name',
+        'project_id',
+        'protocol',
+        'created_at',
+        'updated_at',
+        'provisioning_status',
+        'operating_status',
+        'tls_enabled',
+        'tls_ciphers',
+        'tls_versions',
+        'alpn_protocols',
+        'ca_tls_container_ref',
+        'crl_container_ref',
+        is_admin_state_up='admin_state_up',
+        **tag.TagMixin._tag_query_parameters,
     )
 
     #: Properties
+    #: List of ALPN protocols.
+    alpn_protocols = resource.Body('alpn_protocols', type=list)
     #: Timestamp when the pool was created
     created_at = resource.Body('created_at')
     #: Description for the pool.
@@ -72,3 +89,9 @@ class Pool(resource.Resource, resource.TagMixin):
     tls_versions = resource.Body('tls_versions', type=list)
     #: Timestamp when the pool was updated
     updated_at = resource.Body('updated_at')
+    #: Use TLS for connections to backend member servers *Type: bool*
+    tls_enabled = resource.Body('tls_enabled', type=bool)
+    #: Stores the ca certificate used by backend servers
+    ca_tls_container_ref = resource.Body('ca_tls_container_ref')
+    #: Stores the revocation list file
+    crl_container_ref = resource.Body('crl_container_ref')
