@@ -10,7 +10,6 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from openstack.network import network_service
 from openstack import resource
 
 
@@ -18,15 +17,28 @@ class LoadBalancer(resource.Resource):
     resource_key = 'loadbalancer'
     resources_key = 'loadbalancers'
     base_path = '/lbaas/loadbalancers'
-    service = network_service.NetworkService()
+
+    _allow_unknown_attrs_in_body = True
 
     # capabilities
     allow_create = True
-    allow_get = True
-    allow_update = True
+    allow_fetch = True
+    allow_commit = True
     allow_delete = True
     allow_list = True
 
+    _query_mapping = resource.QueryParameters(
+        'description',
+        'name',
+        'project_id',
+        'provider',
+        'provisioning_status',
+        'tenant_id',
+        'vip_address',
+        'vip_subnet_id',
+        is_admin_state_up='admin_state_up',
+    )
+
     # Properties
     #: Description for the load balancer.
     description = resource.Body('description')
@@ -44,7 +56,9 @@ class LoadBalancer(resource.Resource):
     #: *Type: list of dicts which contain the pool IDs*
     pool_ids = resource.Body('pools', type=list)
     #: The ID of the project this load balancer is associated with.
-    project_id = resource.Body('tenant_id')
+    project_id = resource.Body('project_id', alias='tenant_id')
+    #: Tenant_id (deprecated attribute).
+    tenant_id = resource.Body('tenant_id', deprecated=True)
     #: The name of the provider.
     provider = resource.Body('provider')
     #: Status of load balancer provisioning, e.g. ACTIVE, INACTIVE.
