@@ -10,6 +10,8 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import typing as ty
+
 from openstack import exceptions
 from openstack.orchestration.util import template_utils
 from openstack.orchestration.v1 import resource as _resource
@@ -17,6 +19,7 @@ from openstack.orchestration.v1 import software_config as _sc
 from openstack.orchestration.v1 import software_deployment as _sd
 from openstack.orchestration.v1 import stack as _stack
 from openstack.orchestration.v1 import stack_environment as _stack_environment
+from openstack.orchestration.v1 import stack_event as _stack_event
 from openstack.orchestration.v1 import stack_files as _stack_files
 from openstack.orchestration.v1 import stack_template as _stack_template
 from openstack.orchestration.v1 import template as _template
@@ -24,26 +27,48 @@ from openstack import proxy
 from openstack import resource
 
 
+# TODO(rladntjr4): Some of these methods support lookup by ID, while others
+# support lookup by ID or name. We should choose one and use it consistently.
 class Proxy(proxy.Proxy):
+    _resource_registry = {
+        "resource": _resource.Resource,
+        "software_config": _sc.SoftwareConfig,
+        "software_deployment": _sd.SoftwareDeployment,
+        "stack": _stack.Stack,
+        "stack_environment": _stack_environment.StackEnvironment,
+        "stack_files": _stack_files.StackFiles,
+        "stack_template": _stack_template.StackTemplate,
+    }
 
     def _extract_name_consume_url_parts(self, url_parts):
-        if (len(url_parts) == 3 and url_parts[0] == 'software_deployments'
-                and url_parts[1] == 'metadata'):
+        if (
+            len(url_parts) == 3
+            and url_parts[0] == 'software_deployments'
+            and url_parts[1] == 'metadata'
+        ):
             # Another nice example of totally different URL naming scheme,
             # which we need to repair /software_deployment/metadata/server_id -
             # just replace server_id with metadata to keep further logic
             return ['software_deployment', 'metadata']
-        if (url_parts[0] == 'stacks' and len(url_parts) > 2
-                and not url_parts[2] in ['preview', 'resources']):
+        if (
+            url_parts[0] == 'stacks'
+            and len(url_parts) > 2
+            and url_parts[2] not in ['preview', 'resources']
+        ):
             # orchestrate introduce having stack name and id part of the URL
             # (/stacks/name/id/everything_else), so if on third position we
             # have not a known part - discard it, not to brake further logic
             del url_parts[2]
-        return super(Proxy, self)._extract_name_consume_url_parts(url_parts)
+        return super()._extract_name_consume_url_parts(url_parts)
 
-    def read_env_and_templates(self, template_file=None, template_url=None,
-                               template_object=None, files=None,
-                               environment_files=None):
+    def read_env_and_templates(
+        self,
+        template_file=None,
+        template_url=None,
+        template_object=None,
+        files=None,
+        environment_files=None,
+    ):
         """Read templates and environment content and prepares
         corresponding stack attributes
 
@@ -61,16 +86,20 @@ class Proxy(proxy.Proxy):
         envfiles = dict()
         tpl_files = None
         if environment_files:
-            envfiles, env = \
-                template_utils.process_multiple_environments_and_files(
-                    env_paths=environment_files)
+            (
+                envfiles,
+                env,
+            ) = template_utils.process_multiple_environments_and_files(
+                env_paths=environment_files
+            )
             stack_attrs['environment'] = env
         if template_file or template_url or template_object:
             tpl_files, template = template_utils.get_template_contents(
                 template_file=template_file,
                 template_url=template_url,
                 template_object=template_object,
-                files=files)
+                files=files,
+            )
             stack_attrs['template'] = template
             if tpl_files or envfiles:
                 stack_attrs['files'] = dict(
@@ -95,21 +124,25 @@ class Proxy(proxy.Proxy):
         base_path = None if not preview else '/stacks/preview'
         return self._create(_stack.Stack, base_path=base_path, **attrs)
 
-    def find_stack(self, name_or_id,
-                   ignore_missing=True, resolve_outputs=True):
+    def find_stack(
+        self, name_or_id, ignore_missing=True, resolve_outputs=True
+    ):
         """Find a single stack
 
         :param name_or_id: The name or ID of a stack.
         :param bool ignore_missing: When set to ``False``
-            :class:`~openstack.exceptions.ResourceNotFound` will be
+            :class:`~openstack.exceptions.NotFoundException` will be
             raised when the resource does not exist.
             When set to ``True``, None will be returned when
             attempting to find a nonexistent resource.
         :returns: One :class:`~openstack.orchestration.v1.stack.Stack` or None
         """
-        return self._find(_stack.Stack, name_or_id,
-                          ignore_missing=ignore_missing,
-                          resolve_outputs=resolve_outputs)
+        return self._find(
+            _stack.Stack,
+            name_or_id,
+            ignore_missing=ignore_missing,
+            resolve_outputs=resolve_outputs,
+        )
 
     def stacks(self, **query):
         """Return a generator of stacks
@@ -130,12 +163,12 @@ class Proxy(proxy.Proxy):
         :param resolve_outputs: Whether stack should contain outputs resolved.
 
         :returns: One :class:`~openstack.orchestration.v1.stack.Stack`
-        :raises: :class:`~openstack.exceptions.ResourceNotFound`
+        :raises: :class:`~openstack.exceptions.NotFoundException`
             when no resource can be found.
         """
         return self._get(_stack.Stack, stack, resolve_outputs=resolve_outputs)
 
-    def update_stack(self, stack, preview=False, **attrs):
+    def update_stack(self, stack, *, preview=False, **attrs):
         """Update a stack
 
         :param stack: The value can be the ID of a stack or a
@@ -145,11 +178,11 @@ class Proxy(proxy.Proxy):
 
         :returns: The updated stack
         :rtype: :class:`~openstack.orchestration.v1.stack.Stack`
-        :raises: :class:`~openstack.exceptions.ResourceNotFound`
+        :raises: :class:`~openstack.exceptions.NotFoundException`
             when no resource can be found.
         """
         res = self._get_resource(_stack.Stack, stack, **attrs)
-        return res.update(self, preview)
+        return res.commit(self, preview)
 
     def delete_stack(self, stack, ignore_missing=True):
         """Delete a stack
@@ -158,7 +191,7 @@ class Proxy(proxy.Proxy):
             :class:`~openstack.orchestration.v1.stack.Stack`
             instance.
         :param bool ignore_missing: When set to ``False``
-            :class:`~openstack.exceptions.ResourceNotFound` will be
+            :class:`~openstack.exceptions.NotFoundException` will be
             raised when the stack does not exist.
             When set to ``True``, no exception will be set when
             attempting to delete a nonexistent stack.
@@ -194,6 +227,41 @@ class Proxy(proxy.Proxy):
         res = self._get_resource(_stack.Stack, stack)
         return res.abandon(self)
 
+    def export_stack(self, stack):
+        """Get the stack data in JSON format
+
+        :param stack: The value can be the ID or a name or
+            an instance of :class:`~openstack.orchestration.v1.stack.Stack`
+        :returns: A dictionary containing the stack data.
+        :raises: :class:`~openstack.exceptions.NotFoundException`
+            when no resource can be found.
+        """
+        if isinstance(stack, _stack.Stack):
+            obj = stack
+        else:
+            obj = self._find(_stack.Stack, stack, ignore_missing=False)
+        return obj.export(self)
+
+    def suspend_stack(self, stack):
+        """Suspend a stack status
+
+        :param stack: The value can be either the ID of a stack or an instance
+            of :class:`~openstack.orchestration.v1.stack.Stack`.
+        :returns: ``None``
+        """
+        res = self._get_resource(_stack.Stack, stack)
+        res.suspend(self)
+
+    def resume_stack(self, stack):
+        """Resume a stack status
+
+        :param stack: The value can be either the ID of a stack or an instance
+            of :class:`~openstack.orchestration.v1.stack.Stack`.
+        :returns: ``None``
+        """
+        res = self._get_resource(_stack.Stack, stack)
+        res.resume(self)
+
     def get_stack_template(self, stack):
         """Get template used by a stack
 
@@ -202,7 +270,7 @@ class Proxy(proxy.Proxy):
 
         :returns: One object of
             :class:`~openstack.orchestration.v1.stack_template.StackTemplate`
-        :raises: :class:`~openstack.exceptions.ResourceNotFound`
+        :raises: :class:`~openstack.exceptions.NotFoundException`
             when no resource can be found.
         """
         if isinstance(stack, _stack.Stack):
@@ -210,8 +278,12 @@ class Proxy(proxy.Proxy):
         else:
             obj = self._find(_stack.Stack, stack, ignore_missing=False)
 
-        return self._get(_stack_template.StackTemplate, requires_id=False,
-                         stack_name=obj.name, stack_id=obj.id)
+        return self._get(
+            _stack_template.StackTemplate,
+            requires_id=False,
+            stack_name=obj.name,
+            stack_id=obj.id,
+        )
 
     def get_stack_environment(self, stack):
         """Get environment used by a stack
@@ -221,7 +293,7 @@ class Proxy(proxy.Proxy):
 
         :returns: One object of
             :class:`~openstack.orchestration.v1.stack_environment.StackEnvironment`
-        :raises: :class:`~openstack.exceptions.ResourceNotFound` when no
+        :raises: :class:`~openstack.exceptions.NotFoundException` when no
             resource can be found.
         """
         if isinstance(stack, _stack.Stack):
@@ -229,9 +301,12 @@ class Proxy(proxy.Proxy):
         else:
             obj = self._find(_stack.Stack, stack, ignore_missing=False)
 
-        return self._get(_stack_environment.StackEnvironment,
-                         requires_id=False, stack_name=obj.name,
-                         stack_id=obj.id)
+        return self._get(
+            _stack_environment.StackEnvironment,
+            requires_id=False,
+            stack_name=obj.name,
+            stack_id=obj.id,
+        )
 
     def get_stack_files(self, stack):
         """Get files used by a stack
@@ -241,7 +316,7 @@ class Proxy(proxy.Proxy):
 
         :returns: A dictionary containing the names and contents of all files
             used by the stack.
-        :raises: :class:`~openstack.exceptions.ResourceNotFound`
+        :raises: :class:`~openstack.exceptions.NotFoundException`
             when the stack cannot be found.
         """
         if isinstance(stack, _stack.Stack):
@@ -265,7 +340,7 @@ class Proxy(proxy.Proxy):
             an exception is thrown.
         :rtype: A generator of
             :class:`~openstack.orchestration.v1.resource.Resource`
-        :raises: :class:`~openstack.exceptions.ResourceNotFound`
+        :raises: :class:`~openstack.exceptions.NotFoundException`
             when the stack cannot be found.
         """
         # first try treat the value as a stack object or an ID
@@ -274,8 +349,9 @@ class Proxy(proxy.Proxy):
         else:
             obj = self._find(_stack.Stack, stack, ignore_missing=False)
 
-        return self._list(_resource.Resource, stack_name=obj.name,
-                          stack_id=obj.id, **query)
+        return self._list(
+            _resource.Resource, stack_name=obj.name, stack_id=obj.id, **query
+        )
 
     def create_software_config(self, **attrs):
         """Create a new software config from attributes
@@ -320,14 +396,15 @@ class Proxy(proxy.Proxy):
             config or an instance of
             :class:`~openstack.orchestration.v1.software_config.SoftwareConfig`
         :param bool ignore_missing: When set to ``False``
-            :class:`~openstack.exceptions.ResourceNotFound` will be
+            :class:`~openstack.exceptions.NotFoundException` will be
             raised when the software config does not exist.
             When set to ``True``, no exception will be set when
             attempting to delete a nonexistent software config.
         :returns: ``None``
         """
-        self._delete(_sc.SoftwareConfig, software_config,
-                     ignore_missing=ignore_missing)
+        self._delete(
+            _sc.SoftwareConfig, software_config, ignore_missing=ignore_missing
+        )
 
     def create_software_deployment(self, **attrs):
         """Create a new software deployment from attributes
@@ -365,22 +442,26 @@ class Proxy(proxy.Proxy):
         """
         return self._get(_sd.SoftwareDeployment, software_deployment)
 
-    def delete_software_deployment(self, software_deployment,
-                                   ignore_missing=True):
+    def delete_software_deployment(
+        self, software_deployment, ignore_missing=True
+    ):
         """Delete a software deployment
 
         :param software_deployment: The value can be either the ID of a
             software deployment or an instance of
             :class:`~openstack.orchestration.v1.software_deployment.SoftwareDeployment`
         :param bool ignore_missing: When set to ``False``
-            :class:`~openstack.exceptions.ResourceNotFound` will be
+            :class:`~openstack.exceptions.NotFoundException` will be
             raised when the software deployment does not exist.
             When set to ``True``, no exception will be set when
             attempting to delete a nonexistent software deployment.
         :returns: ``None``
         """
-        self._delete(_sd.SoftwareDeployment, software_deployment,
-                     ignore_missing=ignore_missing)
+        self._delete(
+            _sd.SoftwareDeployment,
+            software_deployment,
+            ignore_missing=ignore_missing,
+        )
 
     def update_software_deployment(self, software_deployment, **attrs):
         """Update a software deployment
@@ -394,11 +475,13 @@ class Proxy(proxy.Proxy):
         :rtype:
             :class:`~openstack.orchestration.v1.software_deployment.SoftwareDeployment`
         """
-        return self._update(_sd.SoftwareDeployment, software_deployment,
-                            **attrs)
+        return self._update(
+            _sd.SoftwareDeployment, software_deployment, **attrs
+        )
 
-    def validate_template(self, template, environment=None, template_url=None,
-                          ignore_errors=None):
+    def validate_template(
+        self, template, environment=None, template_url=None, ignore_errors=None
+    ):
         """Validates a template.
 
         :param template: The stack template on which the validation is
@@ -420,75 +503,154 @@ class Proxy(proxy.Proxy):
         """
         if template is None and template_url is None:
             raise exceptions.InvalidRequest(
-                "'template_url' must be specified when template is None")
+                "'template_url' must be specified when template is None"
+            )
 
         tmpl = _template.Template.new()
-        return tmpl.validate(self, template, environment=environment,
-                             template_url=template_url,
-                             ignore_errors=ignore_errors)
+        return tmpl.validate(
+            self,
+            template,
+            environment=environment,
+            template_url=template_url,
+            ignore_errors=ignore_errors,
+        )
 
-    def wait_for_status(self, res, status='ACTIVE', failures=None,
-                        interval=2, wait=120):
-        """Wait for a resource to be in a particular status.
+    def get_template_contents(
+        self,
+        template_file=None,
+        template_url=None,
+        template_object=None,
+        files=None,
+    ):
+        try:
+            return template_utils.get_template_contents(
+                template_file=template_file,
+                template_url=template_url,
+                template_object=template_object,
+                files=files,
+            )
+        except Exception as e:
+            raise exceptions.SDKException(
+                f"Error in processing template files: {str(e)}"
+            )
 
-        :param res: The resource to wait on to reach the specified status.
-            The resource must have a ``status`` attribute.
-        :type resource: A :class:`~openstack.resource.Resource` object.
-        :param status: Desired status.
-        :param failures: Statuses that would be interpreted as failures.
-        :type failures: :py:class:`list`
-        :param interval: Number of seconds to wait before to consecutive
-            checks. Default to 2.
-        :param wait: Maximum number of seconds to wait before the change.
-            Default to 120.
-        :returns: The resource is returned on success.
-        :raises: :class:`~openstack.exceptions.ResourceTimeout` if transition
-            to the desired status failed to occur in specified seconds.
-        :raises: :class:`~openstack.exceptions.ResourceFailure` if the resource
-            has transited to one of the failure statuses.
-        :raises: :class:`~AttributeError` if the resource does not have a
-            ``status`` attribute.
+    # ========== Stack events ==========
+
+    def stack_events(self, stack, resource_name=None, **attr):
+        """Get a stack events
+
+        :param stack: The value can be the ID of a stack or an instance of
+            :class:`~openstack.orchestration.v1.stack.Stack`
+        :param resource_name: The name of resource. If the resource_name is not
+            None, the base_path changes.
+
+        :returns: A generator of stack_events objects
+        :rtype: :class:`~openstack.orchestration.v1.stack_event.StackEvent`
         """
-        failures = [] if failures is None else failures
-        return resource.wait_for_status(
-            self, res, status, failures, interval, wait)
 
-    def wait_for_delete(self, res, interval=2, wait=120):
+        if isinstance(stack, _stack.Stack):
+            obj = stack
+        else:
+            obj = self._get(_stack.Stack, stack)
+
+        if resource_name:
+            base_path = '/stacks/%(stack_name)s/%(stack_id)s/resources/%(resource_name)s/events'
+            return self._list(
+                _stack_event.StackEvent,
+                stack_name=obj.name,
+                stack_id=obj.id,
+                resource_name=resource_name,
+                base_path=base_path,
+                **attr,
+            )
+
+        return self._list(
+            _stack_event.StackEvent,
+            stack_name=obj.name,
+            stack_id=obj.id,
+            **attr,
+        )
+
+    # ========== Utilities ==========
+
+    def wait_for_status(
+        self,
+        res: resource.ResourceT,
+        status: str,
+        failures: list[str] | None = None,
+        interval: int | float | None = 2,
+        wait: int | None = None,
+        attribute: str = 'status',
+        callback: ty.Callable[[int], None] | None = None,
+    ) -> resource.ResourceT:
+        """Wait for the resource to be in a particular status.
+
+        :param session: The session to use for making this request.
+        :param resource: The resource to wait on to reach the status. The
+            resource must have a status attribute specified via ``attribute``.
+        :param status: Desired status of the resource.
+        :param failures: Statuses that would indicate the transition
+            failed such as 'ERROR'. Defaults to ['ERROR'].
+        :param interval: Number of seconds to wait between checks.
+        :param wait: Maximum number of seconds to wait for transition.
+            Set to ``None`` to wait forever.
+        :param attribute: Name of the resource attribute that contains the
+            status.
+        :param callback: A callback function. This will be called with a single
+            value, progress. This is API specific but is generally a percentage
+            value from 0-100.
+
+        :return: The updated resource.
+        :raises: :class:`~openstack.exceptions.ResourceTimeout` if the
+            transition to status failed to occur in ``wait`` seconds.
+        :raises: :class:`~openstack.exceptions.ResourceFailure` if the resource
+            transitioned to one of the states in ``failures``.
+        :raises: :class:`~AttributeError` if the resource does not have a
+            ``status`` attribute
+        """
+        return resource.wait_for_status(
+            self, res, status, failures, interval, wait, attribute, callback
+        )
+
+    def wait_for_delete(
+        self,
+        res: resource.ResourceT,
+        interval: int = 2,
+        wait: int = 120,
+        callback: ty.Callable[[int], None] | None = None,
+    ) -> resource.ResourceT:
         """Wait for a resource to be deleted.
 
         :param res: The resource to wait on to be deleted.
-        :type resource: A :class:`~openstack.resource.Resource` object.
         :param interval: Number of seconds to wait before to consecutive
-            checks. Default to 2.
+            checks.
         :param wait: Maximum number of seconds to wait before the change.
-            Default to 120.
+        :param callback: A callback function. This will be called with a single
+            value, progress, which is a percentage value from 0-100.
+
         :returns: The resource is returned on success.
         :raises: :class:`~openstack.exceptions.ResourceTimeout` if transition
             to delete failed to occur in the specified seconds.
         """
-        return resource.wait_for_delete(self, res, interval, wait)
-
-    def get_template_contents(
-            self, template_file=None, template_url=None,
-            template_object=None, files=None):
-        try:
-            return template_utils.get_template_contents(
-                template_file=template_file, template_url=template_url,
-                template_object=template_object, files=files)
-        except Exception as e:
-            raise exceptions.SDKException(
-                "Error in processing template files: %s" % str(e))
+        return resource.wait_for_delete(self, res, interval, wait, callback)
 
     def _get_cleanup_dependencies(self):
         return {
-            'orchestration': {
-                'before': ['compute', 'network', 'identity']
-            }
+            'orchestration': {'before': ['compute', 'network', 'identity']}
         }
 
-    def _service_cleanup(self, dry_run=True, client_status_queue=None,
-                         identified_resources=None,
-                         filters=None, resource_evaluation_fn=None):
+    def _service_cleanup(
+        self,
+        dry_run=True,
+        client_status_queue=None,
+        identified_resources=None,
+        filters=None,
+        resource_evaluation_fn=None,
+        skip_resources=None,
+    ):
+        if self.should_skip_resource_cleanup("stack", skip_resources):
+            return
+
         stacks = []
         for obj in self.stacks():
             need_delete = self._service_cleanup_del_res(
@@ -498,7 +660,8 @@ class Proxy(proxy.Proxy):
                 client_status_queue=client_status_queue,
                 identified_resources=identified_resources,
                 filters=filters,
-                resource_evaluation_fn=resource_evaluation_fn)
+                resource_evaluation_fn=resource_evaluation_fn,
+            )
             if not dry_run and need_delete:
                 stacks.append(obj)
 
