@@ -10,42 +10,45 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+
 from openstack.tests.functional import base
 
 
 class BaseBaremetalTest(base.BaseFunctionalTest):
-    min_microversion = None
-    node_id = None
+    min_microversion: str | None = None
+    node_id: str
 
     def setUp(self):
-        super(BaseBaremetalTest, self).setUp()
+        super().setUp()
         self.require_service(
             'baremetal', min_microversion=self.min_microversion
         )
 
     def create_allocation(self, **kwargs):
-        allocation = self.conn.baremetal.create_allocation(**kwargs)
+        allocation = self.operator_cloud.baremetal.create_allocation(**kwargs)
         self.addCleanup(
-            lambda: self.conn.baremetal.delete_allocation(
+            lambda: self.operator_cloud.baremetal.delete_allocation(
                 allocation.id, ignore_missing=True
             )
         )
         return allocation
 
     def create_chassis(self, **kwargs):
-        chassis = self.conn.baremetal.create_chassis(**kwargs)
+        chassis = self.system_admin_cloud.baremetal.create_chassis(**kwargs)
         self.addCleanup(
-            lambda: self.conn.baremetal.delete_chassis(
+            lambda: self.system_admin_cloud.baremetal.delete_chassis(
                 chassis.id, ignore_missing=True
             )
         )
         return chassis
 
     def create_node(self, driver='fake-hardware', **kwargs):
-        node = self.conn.baremetal.create_node(driver=driver, **kwargs)
+        node = self.operator_cloud.baremetal.create_node(
+            driver=driver, **kwargs
+        )
         self.node_id = node.id
         self.addCleanup(
-            lambda: self.conn.baremetal.delete_node(
+            lambda: self.operator_cloud.baremetal.delete_node(
                 self.node_id, ignore_missing=True
             )
         )
@@ -54,9 +57,11 @@ class BaseBaremetalTest(base.BaseFunctionalTest):
 
     def create_port(self, node_id=None, **kwargs):
         node_id = node_id or self.node_id
-        port = self.conn.baremetal.create_port(node_uuid=node_id, **kwargs)
+        port = self.operator_cloud.baremetal.create_port(
+            node_uuid=node_id, **kwargs
+        )
         self.addCleanup(
-            lambda: self.conn.baremetal.delete_port(
+            lambda: self.operator_cloud.baremetal.delete_port(
                 port.id, ignore_missing=True
             )
         )
@@ -64,11 +69,11 @@ class BaseBaremetalTest(base.BaseFunctionalTest):
 
     def create_port_group(self, node_id=None, **kwargs):
         node_id = node_id or self.node_id
-        port_group = self.conn.baremetal.create_port_group(
+        port_group = self.operator_cloud.baremetal.create_port_group(
             node_uuid=node_id, **kwargs
         )
         self.addCleanup(
-            lambda: self.conn.baremetal.delete_port_group(
+            lambda: self.operator_cloud.baremetal.delete_port_group(
                 port_group.id, ignore_missing=True
             )
         )
@@ -76,12 +81,14 @@ class BaseBaremetalTest(base.BaseFunctionalTest):
 
     def create_volume_connector(self, node_id=None, **kwargs):
         node_id = node_id or self.node_id
-        volume_connector = self.conn.baremetal.create_volume_connector(
-            node_uuid=node_id, **kwargs
+        volume_connector = (
+            self.operator_cloud.baremetal.create_volume_connector(
+                node_uuid=node_id, **kwargs
+            )
         )
 
         self.addCleanup(
-            lambda: self.conn.baremetal.delete_volume_connector(
+            lambda: self.operator_cloud.baremetal.delete_volume_connector(
                 volume_connector.id, ignore_missing=True
             )
         )
@@ -89,12 +96,12 @@ class BaseBaremetalTest(base.BaseFunctionalTest):
 
     def create_volume_target(self, node_id=None, **kwargs):
         node_id = node_id or self.node_id
-        volume_target = self.conn.baremetal.create_volume_target(
+        volume_target = self.operator_cloud.baremetal.create_volume_target(
             node_uuid=node_id, **kwargs
         )
 
         self.addCleanup(
-            lambda: self.conn.baremetal.delete_volume_target(
+            lambda: self.operator_cloud.baremetal.delete_volume_target(
                 volume_target.id, ignore_missing=True
             )
         )
@@ -103,11 +110,39 @@ class BaseBaremetalTest(base.BaseFunctionalTest):
     def create_deploy_template(self, **kwargs):
         """Create a new deploy_template from attributes."""
 
-        deploy_template = self.conn.baremetal.create_deploy_template(**kwargs)
+        deploy_template = (
+            self.system_admin_cloud.baremetal.create_deploy_template(**kwargs)
+        )
 
         self.addCleanup(
-            lambda: self.conn.baremetal.delete_deploy_template(
+            lambda: self.system_admin_cloud.baremetal.delete_deploy_template(
                 deploy_template.id, ignore_missing=True
             )
         )
         return deploy_template
+
+    def create_runbook(self, **kwargs):
+        """Create a new runbook from attributes."""
+
+        runbook = self.operator_cloud.baremetal.create_runbook(**kwargs)
+
+        self.addCleanup(
+            lambda: self.operator_cloud.baremetal.delete_runbook(
+                runbook.id, ignore_missing=True
+            )
+        )
+        return runbook
+
+    def create_inspection_rule(self, **kwargs):
+        """Create a new inspection_rule from attributes."""
+
+        inspection_rule = (
+            self.system_admin_cloud.baremetal.create_inspection_rule(**kwargs)
+        )
+
+        self.addCleanup(
+            lambda: self.system_admin_cloud.baremetal.delete_inspection_rule(
+                inspection_rule.id, ignore_missing=True
+            )
+        )
+        return inspection_rule
