@@ -15,17 +15,19 @@ from openstack.tests.functional import base
 
 
 class TestApplicationCredentials(base.BaseFunctionalTest):
-
     def setUp(self):
-        super(TestApplicationCredentials, self).setUp()
+        super().setUp()
         self.user_id = self.operator_cloud.current_user_id
 
     def _create_application_credentials(self):
-        app_creds = self.conn.identity.create_application_credential(
+        app_creds = self.operator_cloud.identity.create_application_credential(
             user=self.user_id, name='app_cred'
         )
-        self.addCleanup(self.conn.identity.delete_application_credential,
-                        self.user_id, app_creds['id'])
+        self.addCleanup(
+            self.operator_cloud.identity.delete_application_credential,
+            self.user_id,
+            app_creds['id'],
+        )
         return app_creds
 
     def test_create_application_credentials(self):
@@ -34,7 +36,7 @@ class TestApplicationCredentials(base.BaseFunctionalTest):
 
     def test_get_application_credential(self):
         app_creds = self._create_application_credentials()
-        app_cred = self.conn.identity.get_application_credential(
+        app_cred = self.operator_cloud.identity.get_application_credential(
             user=self.user_id, application_credential=app_creds['id']
         )
         self.assertEqual(app_cred['id'], app_creds['id'])
@@ -42,7 +44,7 @@ class TestApplicationCredentials(base.BaseFunctionalTest):
 
     def test_application_credentials(self):
         self._create_application_credentials()
-        app_creds = self.conn.identity.application_credentials(
+        app_creds = self.operator_cloud.identity.application_credentials(
             user=self.user_id
         )
         for app_cred in app_creds:
@@ -50,7 +52,7 @@ class TestApplicationCredentials(base.BaseFunctionalTest):
 
     def test_find_application_credential(self):
         app_creds = self._create_application_credentials()
-        app_cred = self.conn.identity.find_application_credential(
+        app_cred = self.operator_cloud.identity.find_application_credential(
             user=self.user_id, name_or_id=app_creds['id']
         )
         self.assertEqual(app_cred['id'], app_creds['id'])
@@ -58,11 +60,12 @@ class TestApplicationCredentials(base.BaseFunctionalTest):
 
     def test_delete_application_credential(self):
         app_creds = self._create_application_credentials()
-        self.conn.identity.delete_application_credential(
+        self.operator_cloud.identity.delete_application_credential(
             user=self.user_id, application_credential=app_creds['id']
         )
-        self.assertRaises(exceptions.NotFoundException,
-                          self.conn.identity.get_application_credential,
-                          user=self.user_id,
-                          application_credential=app_creds['id']
-                          )
+        self.assertRaises(
+            exceptions.NotFoundException,
+            self.operator_cloud.identity.get_application_credential,
+            user=self.user_id,
+            application_credential=app_creds['id'],
+        )
