@@ -27,6 +27,7 @@ BACKUP = {
     "created_at": "2018-04-02T10:35:27.000000",
     "updated_at": "2018-04-03T10:35:27.000000",
     "description": 'description',
+    "encryption_key_id": "fake_encry_id",
     "fail_reason": 'fail reason',
     "id": FAKE_ID,
     "name": "backup001",
@@ -38,14 +39,13 @@ BACKUP = {
     "has_dependent_backups": False,
     "os-backup-project-attr:project_id": "2c67a14be9314c5dae2ee6c4ec90cf0b",
     "user_id": "515ba0dd59f84f25a6a084a45d8d93b2",
-    "metadata": {"key": "value"}
+    "metadata": {"key": "value"},
 }
 
 
 class TestBackup(base.TestCase):
-
     def setUp(self):
-        super(TestBackup, self).setUp()
+        super().setUp()
         self.resp = mock.Mock()
         self.resp.body = None
         self.resp.json = mock.Mock(return_value=self.resp.body)
@@ -55,7 +55,7 @@ class TestBackup(base.TestCase):
         self.sess = mock.Mock(spec=adapter.Adapter)
         self.sess.get = mock.Mock()
         self.sess.post = mock.Mock(return_value=self.resp)
-        self.sess.default_microversion = None
+        self.sess.default_microversion = "3.64"
 
     def test_basic(self):
         sot = backup.Backup(BACKUP)
@@ -65,22 +65,25 @@ class TestBackup(base.TestCase):
         self.assertTrue(sot.allow_create)
         self.assertTrue(sot.allow_delete)
         self.assertTrue(sot.allow_list)
-        self.assertTrue(sot.allow_get)
         self.assertTrue(sot.allow_fetch)
+        self.assertTrue(sot.allow_commit)
+        self.assertIsNotNone(sot._max_microversion)
 
         self.assertDictEqual(
             {
-                "all_tenants": "all_tenants",
                 "limit": "limit",
                 "marker": "marker",
-                "name": "name",
+                "offset": "offset",
                 "project_id": "project_id",
+                "name": "name",
+                "status": "status",
+                "volume_id": "volume_id",
                 "sort_dir": "sort_dir",
                 "sort_key": "sort_key",
-                "status": "status",
-                "volume_id": "volume_id"
+                "sort": "sort",
+                "all_projects": "all_tenants",
             },
-            sot._query_mapping._mapping
+            sot._query_mapping._mapping,
         )
 
     def test_create(self):
@@ -98,12 +101,15 @@ class TestBackup(base.TestCase):
         self.assertEqual(BACKUP["object_count"], sot.object_count)
         self.assertEqual(BACKUP["is_incremental"], sot.is_incremental)
         self.assertEqual(BACKUP["size"], sot.size)
-        self.assertEqual(BACKUP["has_dependent_backups"],
-                         sot.has_dependent_backups)
-        self.assertEqual(BACKUP['os-backup-project-attr:project_id'],
-                         sot.project_id)
+        self.assertEqual(
+            BACKUP["has_dependent_backups"], sot.has_dependent_backups
+        )
+        self.assertEqual(
+            BACKUP['os-backup-project-attr:project_id'], sot.project_id
+        )
         self.assertEqual(BACKUP['metadata'], sot.metadata)
         self.assertEqual(BACKUP['user_id'], sot.user_id)
+        self.assertEqual(BACKUP['encryption_key_id'], sot.encryption_key_id)
 
     def test_create_incremental(self):
         sot = backup.Backup(is_incremental=True)
@@ -124,8 +130,8 @@ class TestBackup(base.TestCase):
                     'incremental': True,
                 }
             },
-            microversion=None,
-            params={}
+            microversion="3.64",
+            params={},
         )
 
         sot2.create(self.sess)
@@ -137,62 +143,108 @@ class TestBackup(base.TestCase):
                     'incremental': False,
                 }
             },
-            microversion=None,
-            params={}
+            microversion="3.64",
+            params={},
         )
 
+    def test_export(self):
+        sot = backup.Backup(**BACKUP)
+
+        create_response = mock.Mock()
+        create_response.status_code = 200
+        create_response.json.return_value = {}
+        create_response.headers = {}
+        self.sess.get.return_value = create_response
+        url = f'backups/{FAKE_ID}/export_record'
+        sot.export(self.sess)
+        self.sess.get.assert_called_with(url)
+
     def test_restore(self):
         sot = backup.Backup(**BACKUP)
 
+        restore_response = mock.Mock()
+        restore_response.status_code = 202
+        restore_response.json.return_value = {
+            "restore": {
+                "backup_id": "back",
+                "volume_id": "vol",
+                "volume_name": "name",
+            }
+        }
+        restore_response.headers = {}
+        self.sess.post.return_value = restore_response
+
         self.assertEqual(sot, sot.restore(self.sess, 'vol', 'name'))
 
-        url = 'backups/%s/restore' % FAKE_ID
+        url = f'backups/{FAKE_ID}/restore'
         body = {"restore": {"volume_id": "vol", "name": "name"}}
         self.sess.post.assert_called_with(url, json=body)
 
     def test_restore_name(self):
         sot = backup.Backup(**BACKUP)
 
+        restore_response = mock.Mock()
+        restore_response.status_code = 202
+        restore_response.json.return_value = {
+            "restore": {
+                "backup_id": "back",
+                "volume_id": "vol",
+                "volume_name": "name",
+            }
+        }
+        restore_response.headers = {}
+        self.sess.post.return_value = restore_response
+
         self.assertEqual(sot, sot.restore(self.sess, name='name'))
 
-        url = 'backups/%s/restore' % FAKE_ID
+        url = f'backups/{FAKE_ID}/restore'
         body = {"restore": {"name": "name"}}
         self.sess.post.assert_called_with(url, json=body)
 
     def test_restore_vol_id(self):
         sot = backup.Backup(**BACKUP)
 
+        restore_response = mock.Mock()
+        restore_response.status_code = 202
+        restore_response.json.return_value = {
+            "restore": {
+                "backup_id": "back",
+                "volume_id": "vol",
+                "volume_name": "name",
+            }
+        }
+        restore_response.headers = {}
+        self.sess.post.return_value = restore_response
+
         self.assertEqual(sot, sot.restore(self.sess, volume_id='vol'))
 
-        url = 'backups/%s/restore' % FAKE_ID
+        url = f'backups/{FAKE_ID}/restore'
         body = {"restore": {"volume_id": "vol"}}
         self.sess.post.assert_called_with(url, json=body)
 
     def test_restore_no_params(self):
         sot = backup.Backup(**BACKUP)
 
-        self.assertRaises(
-            exceptions.SDKException,
-            sot.restore,
-            self.sess
-        )
+        self.assertRaises(exceptions.SDKException, sot.restore, self.sess)
 
     def test_force_delete(self):
         sot = backup.Backup(**BACKUP)
 
         self.assertIsNone(sot.force_delete(self.sess))
 
-        url = 'backups/%s/action' % FAKE_ID
-        body = {'os-force_delete': {}}
+        url = f'backups/{FAKE_ID}/action'
+        body = {'os-force_delete': None}
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
 
-    def test_reset(self):
+    def test_reset_status(self):
         sot = backup.Backup(**BACKUP)
 
-        self.assertIsNone(sot.reset(self.sess, 'new_status'))
+        self.assertIsNone(sot.reset_status(self.sess, 'new_status'))
 
-        url = 'backups/%s/action' % FAKE_ID
+        url = f'backups/{FAKE_ID}/action'
         body = {'os-reset_status': {'status': 'new_status'}}
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
