@@ -65,9 +65,8 @@ FAKE_CREATE_RESP = {
 
 
 class TestCluster(base.TestCase):
-
     def setUp(self):
-        super(TestCluster, self).setUp()
+        super().setUp()
 
     def test_basic(self):
         sot = cluster.Cluster()
@@ -102,13 +101,17 @@ class TestCluster(base.TestCase):
         self.assertEqual(FAKE['dependents'], sot.dependents)
         self.assertTrue(sot.is_profile_only)
 
-        self.assertDictEqual({"limit": "limit",
-                              "marker": "marker",
-                              "name": "name",
-                              "status": "status",
-                              "sort": "sort",
-                              "global_project": "global_project"},
-                             sot._query_mapping._mapping)
+        self.assertDictEqual(
+            {
+                "limit": "limit",
+                "marker": "marker",
+                "name": "name",
+                "status": "status",
+                "sort": "sort",
+                "global_project": "global_project",
+            },
+            sot._query_mapping._mapping,
+        )
 
     def test_scale_in(self):
         sot = cluster.Cluster(**FAKE)
@@ -118,10 +121,9 @@ class TestCluster(base.TestCase):
         sess = mock.Mock()
         sess.post = mock.Mock(return_value=resp)
         self.assertEqual('', sot.scale_in(sess, 3))
-        url = 'clusters/%s/actions' % sot.id
+        url = f'clusters/{sot.id}/actions'
         body = {'scale_in': {'count': 3}}
-        sess.post.assert_called_once_with(url,
-                                          json=body)
+        sess.post.assert_called_once_with(url, json=body)
 
     def test_scale_out(self):
         sot = cluster.Cluster(**FAKE)
@@ -131,10 +133,9 @@ class TestCluster(base.TestCase):
         sess = mock.Mock()
         sess.post = mock.Mock(return_value=resp)
         self.assertEqual('', sot.scale_out(sess, 3))
-        url = 'clusters/%s/actions' % sot.id
+        url = f'clusters/{sot.id}/actions'
         body = {'scale_out': {'count': 3}}
-        sess.post.assert_called_once_with(url,
-                                          json=body)
+        sess.post.assert_called_once_with(url, json=body)
 
     def test_resize(self):
         sot = cluster.Cluster(**FAKE)
@@ -144,10 +145,9 @@ class TestCluster(base.TestCase):
         sess = mock.Mock()
         sess.post = mock.Mock(return_value=resp)
         self.assertEqual('', sot.resize(sess, foo='bar', zoo=5))
-        url = 'clusters/%s/actions' % sot.id
+        url = f'clusters/{sot.id}/actions'
         body = {'resize': {'foo': 'bar', 'zoo': 5}}
-        sess.post.assert_called_once_with(url,
-                                          json=body)
+        sess.post.assert_called_once_with(url, json=body)
 
     def test_add_nodes(self):
         sot = cluster.Cluster(**FAKE)
@@ -157,10 +157,9 @@ class TestCluster(base.TestCase):
         sess = mock.Mock()
         sess.post = mock.Mock(return_value=resp)
         self.assertEqual('', sot.add_nodes(sess, ['node-33']))
-        url = 'clusters/%s/actions' % sot.id
+        url = f'clusters/{sot.id}/actions'
         body = {'add_nodes': {'nodes': ['node-33']}}
-        sess.post.assert_called_once_with(url,
-                                          json=body)
+        sess.post.assert_called_once_with(url, json=body)
 
     def test_del_nodes(self):
         sot = cluster.Cluster(**FAKE)
@@ -170,10 +169,9 @@ class TestCluster(base.TestCase):
         sess = mock.Mock()
         sess.post = mock.Mock(return_value=resp)
         self.assertEqual('', sot.del_nodes(sess, ['node-11']))
-        url = 'clusters/%s/actions' % sot.id
+        url = f'clusters/{sot.id}/actions'
         body = {'del_nodes': {'nodes': ['node-11']}}
-        sess.post.assert_called_once_with(url,
-                                          json=body)
+        sess.post.assert_called_once_with(url, json=body)
 
     def test_del_nodes_with_params(self):
         sot = cluster.Cluster(**FAKE)
@@ -186,15 +184,14 @@ class TestCluster(base.TestCase):
             'destroy_after_deletion': True,
         }
         self.assertEqual('', sot.del_nodes(sess, ['node-11'], **params))
-        url = 'clusters/%s/actions' % sot.id
+        url = f'clusters/{sot.id}/actions'
         body = {
             'del_nodes': {
                 'nodes': ['node-11'],
                 'destroy_after_deletion': True,
             }
         }
-        sess.post.assert_called_once_with(url,
-                                          json=body)
+        sess.post.assert_called_once_with(url, json=body)
 
     def test_replace_nodes(self):
         sot = cluster.Cluster(**FAKE)
@@ -204,10 +201,9 @@ class TestCluster(base.TestCase):
         sess = mock.Mock()
         sess.post = mock.Mock(return_value=resp)
         self.assertEqual('', sot.replace_nodes(sess, {'node-22': 'node-44'}))
-        url = 'clusters/%s/actions' % sot.id
+        url = f'clusters/{sot.id}/actions'
         body = {'replace_nodes': {'nodes': {'node-22': 'node-44'}}}
-        sess.post.assert_called_once_with(url,
-                                          json=body)
+        sess.post.assert_called_once_with(url, json=body)
 
     def test_policy_attach(self):
         sot = cluster.Cluster(**FAKE)
@@ -221,15 +217,14 @@ class TestCluster(base.TestCase):
         }
         self.assertEqual('', sot.policy_attach(sess, 'POLICY', **params))
 
-        url = 'clusters/%s/actions' % sot.id
+        url = f'clusters/{sot.id}/actions'
         body = {
             'policy_attach': {
                 'policy_id': 'POLICY',
                 'enabled': True,
             }
         }
-        sess.post.assert_called_once_with(url,
-                                          json=body)
+        sess.post.assert_called_once_with(url, json=body)
 
     def test_policy_detach(self):
         sot = cluster.Cluster(**FAKE)
@@ -240,10 +235,9 @@ class TestCluster(base.TestCase):
         sess.post = mock.Mock(return_value=resp)
         self.assertEqual('', sot.policy_detach(sess, 'POLICY'))
 
-        url = 'clusters/%s/actions' % sot.id
+        url = f'clusters/{sot.id}/actions'
         body = {'policy_detach': {'policy_id': 'POLICY'}}
-        sess.post.assert_called_once_with(url,
-                                          json=body)
+        sess.post.assert_called_once_with(url, json=body)
 
     def test_policy_update(self):
         sot = cluster.Cluster(**FAKE)
@@ -252,20 +246,12 @@ class TestCluster(base.TestCase):
         resp.json = mock.Mock(return_value='')
         sess = mock.Mock()
         sess.post = mock.Mock(return_value=resp)
-        params = {
-            'enabled': False
-        }
+        params = {'enabled': False}
         self.assertEqual('', sot.policy_update(sess, 'POLICY', **params))
 
-        url = 'clusters/%s/actions' % sot.id
-        body = {
-            'policy_update': {
-                'policy_id': 'POLICY',
-                'enabled': False
-            }
-        }
-        sess.post.assert_called_once_with(url,
-                                          json=body)
+        url = f'clusters/{sot.id}/actions'
+        body = {'policy_update': {'policy_id': 'POLICY', 'enabled': False}}
+        sess.post.assert_called_once_with(url, json=body)
 
     def test_check(self):
         sot = cluster.Cluster(**FAKE)
@@ -275,10 +261,9 @@ class TestCluster(base.TestCase):
         sess = mock.Mock()
         sess.post = mock.Mock(return_value=resp)
         self.assertEqual('', sot.check(sess))
-        url = 'clusters/%s/actions' % sot.id
+        url = f'clusters/{sot.id}/actions'
         body = {'check': {}}
-        sess.post.assert_called_once_with(url,
-                                          json=body)
+        sess.post.assert_called_once_with(url, json=body)
 
     def test_recover(self):
         sot = cluster.Cluster(**FAKE)
@@ -288,10 +273,9 @@ class TestCluster(base.TestCase):
         sess = mock.Mock()
         sess.post = mock.Mock(return_value=resp)
         self.assertEqual('', sot.recover(sess))
-        url = 'clusters/%s/actions' % sot.id
+        url = f'clusters/{sot.id}/actions'
         body = {'recover': {}}
-        sess.post.assert_called_once_with(url,
-                                          json=body)
+        sess.post.assert_called_once_with(url, json=body)
 
     def test_operation(self):
         sot = cluster.Cluster(**FAKE)
@@ -301,10 +285,9 @@ class TestCluster(base.TestCase):
         sess = mock.Mock()
         sess.post = mock.Mock(return_value=resp)
         self.assertEqual('', sot.op(sess, 'dance', style='tango'))
-        url = 'clusters/%s/ops' % sot.id
+        url = f'clusters/{sot.id}/ops'
         body = {'dance': {'style': 'tango'}}
-        sess.post.assert_called_once_with(url,
-                                          json=body)
+        sess.post.assert_called_once_with(url, json=body)
 
     def test_force_delete(self):
         sot = cluster.Cluster(**FAKE)
@@ -319,6 +302,6 @@ class TestCluster(base.TestCase):
 
         res = sot.force_delete(sess)
         self.assertEqual(fake_action_id, res.id)
-        url = 'clusters/%s' % sot.id
+        url = f'clusters/{sot.id}'
         body = {'force': True}
         sess.delete.assert_called_once_with(url, json=body)
