@@ -53,6 +53,7 @@ from openstack.network.v2 import qos_bandwidth_limit_rule
 from openstack.network.v2 import qos_dscp_marking_rule
 from openstack.network.v2 import qos_minimum_bandwidth_rule
 from openstack.network.v2 import qos_minimum_packet_rate_rule
+from openstack.network.v2 import qos_packet_rate_limit_rule
 from openstack.network.v2 import qos_policy
 from openstack.network.v2 import qos_rule_type
 from openstack.network.v2 import quota
@@ -1232,6 +1233,82 @@ class TestNetworkQosMinimumPacketRate(TestNetworkProxy):
         )
 
 
+class TestNetworkQosPacketRateLimitRule(TestNetworkProxy):
+    def test_qos_packet_rate_limit_rule_create_attrs(self):
+        self.verify_create(
+            self.proxy.create_qos_packet_rate_limit_rule,
+            qos_packet_rate_limit_rule.QoSPacketRateLimitRule,
+            method_kwargs={'qos_policy': QOS_POLICY_ID},
+            expected_kwargs={'qos_policy_id': QOS_POLICY_ID},
+        )
+
+    def test_qos_packet_rate_limit_rule_delete(self):
+        self.verify_delete(
+            self.proxy.delete_qos_packet_rate_limit_rule,
+            qos_packet_rate_limit_rule.QoSPacketRateLimitRule,
+            ignore_missing=False,
+            method_args=["resource_or_id", QOS_POLICY_ID],
+            expected_args=["resource_or_id"],
+            expected_kwargs={'qos_policy_id': QOS_POLICY_ID},
+        )
+
+    def test_qos_packet_rate_limit_rule_delete_ignore(self):
+        self.verify_delete(
+            self.proxy.delete_qos_packet_rate_limit_rule,
+            qos_packet_rate_limit_rule.QoSPacketRateLimitRule,
+            ignore_missing=True,
+            method_args=["resource_or_id", QOS_POLICY_ID],
+            expected_args=["resource_or_id"],
+            expected_kwargs={'qos_policy_id': QOS_POLICY_ID},
+        )
+
+    def test_qos_packet_rate_limit_rule_find(self):
+        policy = qos_policy.QoSPolicy.new(id=QOS_POLICY_ID)
+        self._verify(
+            'openstack.proxy.Proxy._find',
+            self.proxy.find_qos_packet_rate_limit_rule,
+            method_args=['rule_id', policy],
+            expected_args=[
+                qos_packet_rate_limit_rule.QoSPacketRateLimitRule,
+                'rule_id',
+            ],
+            expected_kwargs={
+                'ignore_missing': True,
+                'qos_policy_id': QOS_POLICY_ID,
+            },
+        )
+
+    def test_qos_packet_rate_limit_rule_get(self):
+        self.verify_get(
+            self.proxy.get_qos_packet_rate_limit_rule,
+            qos_packet_rate_limit_rule.QoSPacketRateLimitRule,
+            method_kwargs={'qos_policy': QOS_POLICY_ID},
+            expected_kwargs={'qos_policy_id': QOS_POLICY_ID},
+        )
+
+    def test_qos_packet_rate_limit_rules(self):
+        self.verify_list(
+            self.proxy.qos_packet_rate_limit_rules,
+            qos_packet_rate_limit_rule.QoSPacketRateLimitRule,
+            method_kwargs={'qos_policy': QOS_POLICY_ID},
+            expected_kwargs={'qos_policy_id': QOS_POLICY_ID},
+        )
+
+    def test_qos_packet_rate_limit_rule_update(self):
+        policy = qos_policy.QoSPolicy.new(id=QOS_POLICY_ID)
+        self._verify(
+            'openstack.network.v2._proxy.Proxy._update',
+            self.proxy.update_qos_packet_rate_limit_rule,
+            method_args=['rule_id', policy],
+            method_kwargs={'foo': 'bar'},
+            expected_args=[
+                qos_packet_rate_limit_rule.QoSPacketRateLimitRule,
+                'rule_id',
+            ],
+            expected_kwargs={'qos_policy_id': QOS_POLICY_ID, 'foo': 'bar'},
+        )
+
+
 class TestNetworkQosRuleType(TestNetworkProxy):
     def test_qos_rule_type_find(self):
         self.verify_find(
